%define uname   garglk
%define rdns    io.github.garglk

Name:           gargoyle
Version:        2023.1
Release:        %mkrel 2
Summary:        Graphical player for Interactive Fiction games
Group:          Games/Adventure
# For the reference, Gargoyle used to include nonfree content,
# hence its previous packaged name gargoyle-free in sync with Debian.
# Now upstream has done great work on this and licenses are all free,
# check License.txt for details.
License:        GPLv3+ and BSD and MIT and Artistic 2.0 and OFL
URL:            https://ccxvii.net/gargoyle/
Source0:        https://github.com/garglk/garglk/archive/%{version}/%{uname}-%{version}.tar.gz
Patch0:         ftbfs_gcc14.patch

BuildRequires:  cmake
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(speech-dispatcher)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Widgets)

Obsoletes:      gargoyle-free < 1:2019.1.1
Provides:       gargoyle-free = 1:%{version}-%{release}

%description
Gargoyle is an Interactive Fiction (text adventure) player that supports all
the major interactive fiction formats.

Most interactive fiction is distributed as portable game files. These portable
game files come in many formats. In the past, you used to have to download a
separate player (interpreter) for each format of IF you wanted to play.
Instead, Gargoyle provides an unified player.

Gargoyle is based on the standard interpreters for the formats it supports:
Adrift, AdvSys, AGiliTy, Alan2, Alan3, Quest, JACL, Level 9, Magnetic, SAGA,
TADS2, TADS3, Z-code and Glulxe.

Gargoyle also features graphics, sounds and Unicode support.

You can find hundreds of games at :
- the IF database : http://ifdb.tads.org
- the IF archive : http://ifarchive.org

Limitations:
* While Gargoyle can display in-game pictures, it does not provide a way to
display the cover art present in some Blorb archives.

* The TADS interpreter doesn't support HTML TADS; you can play the games, but
will miss the hyperlinks.

%prep
%autosetup -p1 -n %{uname}-%{version}

%build
%cmake \
  -DBUILD_SHARED_LIBS=OFF \
  -DCMAKE_INSTALL_BINDIR=%{_gamesbindir} \
  -DINSTALL_GARGLKINI=ON
%cmake_build

%install
%cmake_install

# Not packaging shared library for now.
rm -rf %{buildroot}%{_libdir}
rm -rf %{buildroot}%{_includedir}

%files
%license License.txt licenses/*
%doc README.md
%{_datadir}/applications/%{rdns}.Gargoyle.desktop
%{_datadir}/applications/%{rdns}.GargoyleEditConfig.desktop
%{_datadir}/fonts/%{name}/
%{_datadir}/metainfo/%{rdns}.Gargoyle.appdata.xml
%{_datadir}/mime/packages/interactive-fiction.xml
%{_datadir}/%{rdns}/
%{_gamesbindir}/%{name}
%{_iconsdir}/%{rdns}.Gargoyle.png
%{_iconsdir}/hicolor/32x32/mimetypes/*.png
%{_libexecdir}/%{name}/
%{_mandir}/man6/%{name}.6*
%config %{_sysconfdir}/garglk.ini


%changelog
* Fri May 17 2024 daviddavid <daviddavid> 2023.1-2.mga10
+ Revision: 2064535
- add debian patch to fix build with GCC 14

* Sun Feb 11 2024 akien <akien> 2023.1-1.mga10
+ Revision: 2040379
- Version 2023.1

* Mon Apr 04 2022 umeabot <umeabot> 2022.1-3.mga9
+ Revision: 1842972
- Mageia 9 Mass Rebuild

* Fri Feb 18 2022 akien <akien> 2022.1-2.mga9
+ Revision: 1781105
- Sync garglk.ini install patch with the one merged upstream

* Mon Jan 31 2022 akien <akien> 2022.1-1.mga9
+ Revision: 1770720
- Version 2022.1
- Switch to CMake buildsystem
- Switch from GTK+2/SDL to Qt5/SDL2
- Compile support for speed-dispatcher

* Wed Oct 21 2020 akien <akien> 2019.1.1-1.mga8
+ Revision: 1637646
- Version 2019.1.1.
- No longer includes any nonfree component, so we use upstream tarball.
- Renamed package to 'gargoyle' since there's no more nonfree version to
  disambiguate with.
- Clarified licenses.
- Rename spec file following package rename
- Rename gargoyle-free to gargoyle, new upstream version is 100%% free

* Thu Feb 13 2020 umeabot <umeabot> 1:2011.1-13.mga8
+ Revision: 1512382
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 1:2011.1-12.mga7
+ Revision: 1297825
- Mageia 7 Mass Rebuild

* Mon May 07 2018 daviddavid <daviddavid> 1:2011.1-11.mga7
+ Revision: 1226898
- fix FTBFS with GCC6 by using -std=gnu++98

* Sun Feb 14 2016 umeabot <umeabot> 1:2011.1-10.mga6
+ Revision: 960231
- Mageia 6 Mass Rebuild

* Mon Nov 09 2015 daviddavid <daviddavid> 1:2011.1-9.mga6
+ Revision: 899867
- fix compilation with gcc5: add -fgnu89-inline to CFLAGS

* Mon Jan 12 2015 akien <akien> 1:2011.1-8.mga5
+ Revision: 810055
- Fix icon name

* Mon Jan 12 2015 akien <akien> 1:2011.1-7.mga5
+ Revision: 810033
+ rebuild (emptylog)

* Wed Oct 15 2014 umeabot <umeabot> 1:2011.1-6.r619.3.mga5
+ Revision: 747216
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1:2011.1-6.r619.2.mga5
+ Revision: 679416
- Mageia 5 Mass Rebuild

* Thu Sep 04 2014 akien <akien> 1:2011.1-6.r619.1.mga5
+ Revision: 672126
+ rebuild (emptylog)

* Thu Sep 04 2014 akien <akien> 1:2011.1-5.mga5
+ Revision: 672115
- Install missing desktop entry, icon and mandatory config file
- Fix Debian patch to point to the correct %%_libexecdir
- Use a static build to circumvent linking issues

* Mon Oct 21 2013 umeabot <umeabot> 1:2011.1-4.mga4
+ Revision: 539294
- Mageia 4 Mass Rebuild

* Thu Sep 26 2013 akien <akien> 1:2011.1-3.mga4
+ Revision: 486626
- Proper archive for 2011.1 without nonfree content
- Use of pkgconfig in BRs when possible
- Updated README.mageia
- Reverted changes to "ignore_bundled_libraries.patch"
- New repacked archive adapted to version 2011.1
- Fixed mixed use of tabs and spaces
- Now one line per BR
- Added support for Alan2 and Alan3 (now under the Artistic License 2.0)
- Repacked the archive to remove nonfree content
- Fixed patch "ignore_bundled_libraries.patch"

* Mon Jun 03 2013 fwang <fwang> 1:2011.1-2.mga4
+ Revision: 435903
- rebuild for new libpng

* Wed Feb 27 2013 fwang <fwang> 1:2011.1-1.mga3
+ Revision: 400470
- add dir
- update file list
- update file list
- link m
- more link
- fix linkage
- update switches
- update switch
- update build script
- add epoch to fix upgrading
- new version 2011.1

* Wed Feb 27 2013 fwang <fwang> 20090825-8.mga3
+ Revision: 400448
- use ldflags

* Wed Feb 27 2013 fwang <fwang> 20090825-7.mga3
+ Revision: 400444
- fix linkage
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ malo <malo>
- fix RPM group

* Tue Sep 20 2011 fwang <fwang> 20090825-5.mga2
+ Revision: 145980
- fix typo
- fix build with latest libpng 1.5

* Wed Jan 26 2011 stormi <stormi> 20090825-5.mga1
+ Revision: 41517
- mgaification
- imported package gargoyle-free

